<?php
/*
	Plugin Name: Google Analytics Tracking-Code Plugin
	Plugin URI: http://perishablepress.com/google-analytics-plugin/
	Description: Fügt den Google Analytics Tracking Code in Deine Webseite ein.
	Author: Jeff Starr 
	Kirsten Schelper added one line (30) to anonymize IPs and translated it
	Version: 2012-04-09
	Usage: Visit the "Google Analytics" options page to enter your GA ID and done.
	
	
*/

// require minimum version of WordPress
add_action('admin_init', 'require_wp_version');
function require_wp_version() {
	global $wp_version;
	$plugin = plugin_basename(__FILE__);
	$plugin_data = get_plugin_data(__FILE__, false);

	if (version_compare($wp_version, "3.3", "<")) {
		if (is_plugin_active($plugin)) {
			deactivate_plugins($plugin);
			$msg =  '<p><strong>' . $plugin_data['Name'] . '</strong> braucht WordPress 3.3 oder höher, das PlugIn wurde deaktiviert!</p>';
			$msg .= '<p>Mache bitte ein Upgrade und versuche es noch einmal.</p><p>Zurück zum <a href="' .admin_url() . '">WordPress Admin Bereich</a>.</p>';
			wp_die($msg);
		}
	}
}

// Google Analytics Tracking Code (ga.js)
// @ http://code.google.com/apis/analytics/docs/tracking/asyncUsageGuide.html
// Kirsten added anonymize IP in line 30
function google_analytics_tracking_code(){ 
	$options = get_option('ga_options'); 
	if ($options['ga_enable']) { ?>

		<script type="text/javascript">
		  var _gaq = _gaq || [];
		  _gaq.push(['_gat._anonymizeIp']);
		  _gaq.push(['_setAccount', '<?php echo $options['ga_id']; ?>']);
		  _gaq.push(['_trackPageview']);
		
		  (function() {
		    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
		    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
		    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
		  })();
		</script>

<?php }
}

// include GA tracking code before the closing </head> tag
add_action('wp_head', 'google_analytics_tracking_code');

// display settings link on plugin page
add_filter ('plugin_action_links', 'ga_plugin_action_links', 10, 2);
function ga_plugin_action_links($links, $file) {
	if ($file == plugin_basename(__FILE__)) {
		$ga_links = '<a href="'. get_admin_url() .'options-general.php?page=google-analytics-plugin/google-analytics-plugin.php">'. __('Settings') .'</a>';
		array_unshift($links, $ga_links);
	}
	return $links;
}

// remove plugin settings after deletion
register_uninstall_hook (__FILE__, 'ga_delete_plugin_options');
function ga_delete_plugin_options() {
	delete_option('ga_options');
}

// define default settings
register_activation_hook (__FILE__, 'ga_add_defaults');
function ga_add_defaults() {
	$tmp = get_option('ga_options');
	if(($tmp['default_options'] == '1') || (!is_array($tmp))) {
		$arr = array('ga_id' => 'UA-XXXXX-X');
		update_option('ga_options', $arr);
	}
}

// whitelist settings
add_action ('admin_init', 'ga_init');
function ga_init() {
	register_setting('ga_plugin_options', 'ga_options', 'ga_validate_options');
}

// sanitize and validate input
function ga_validate_options($input) {

	if (!isset($input['ga_enable'])) $input['ga_enable'] = null;
	$input['ga_enable'] = ($input['ga_enable'] == 1 ? 1 : 0);

	$input['ga_id'] = wp_filter_nohtml_kses($input['ga_id']);
	return $input;
}

// add the options page
add_action ('admin_menu', 'ga_add_options_page');
function ga_add_options_page() {
	add_options_page('Google Analytics', 'Google Analytics', 'manage_options', __FILE__, 'ga_render_form');
}

// create the options page
function ga_render_form() { ?>

	<div class="wrap">
		<?php screen_icon(); ?>
		<h2><?php _e('Google Analytics Tracking Code') ?></h2>
		<p><?php _e('GA ID eintragen, speichern, fertig.') ?></p>

		<form method="post" action="options.php">
			<?php settings_fields('ga_plugin_options'); ?>
			<?php $options = get_option('ga_options'); ?>

			<table class="form-table">
				<tr>
					<th scope="row"><label class="description" for="ga_options[ga_id]"><?php _e('GA property ID') ?></label></th>
					<td><input type="text" size="20" maxlength="20" name="ga_options[ga_id]" value="<?php echo $options['ga_id']; ?>" /></td>
				</tr>
				<tr valign="top">
					<th scope="row"><label class="description" for="ga_options[ga_enable]"><?php _e('Google Analytics aktivieren') ?></label></th>
					<td>
						<input name="ga_options[ga_enable]" type="checkbox" value="1" <?php if (isset($options['ga_enable'])) { checked('1', $options['ga_enable']); } ?> /> 
						<?php _e('Den GA Tracking Code in die Webseite einbetten?') ?>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row"><label class="description" for="ga_options[default_options]"><?php _e('Restore Default Settings') ?></label></th>
					<td>
						<input name="ga_options[default_options]" type="checkbox" value="1" <?php if (isset($options['default_options'])) { checked('1', $options['default_options']); } ?> /> 
						<?php _e('Originalzustand bei Aktivierung/Deaktivierung des PlugIns wieder herstellen') ?><br /><em><?php _e('Tipp: Wenn hier kein Häkchens gesetzt ist, merkt sich WordPress  die Einstellungen') ?></em>
					</td>
				</tr>
			</table>
			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e('Einstellungen speichern') ?>" />
			</p>
		</form>
		<p><a href="#" title="..."><?php _e('Learn more about this WordPress plugin and other Google Analytics plugins') ?></a></p>
	</div>

<?php } ?>